@@ -31,6 +31,7 @@ pub struct Config {
     lowercase: bool,
 
     /// Separator for splitting lines. It is possible to define multiple separators.
+    /// Newline is always a separator
     #[structopt(short, long, default_value = " ")]
     separators: Vec<char>,
 
@@ -38,11 +39,11 @@ pub struct Config {
     #[structopt(short, long, parse(from_os_str))]
     file: Option<PathBuf>,
 
-    /// Path to file containing the first line. Remaining lines will be ignored.
+    /// Path to file containing the first line. The complete file will be processed.
     #[structopt(long)]
     file1: Option<PathBuf>,
 
-    /// Path to file containing the second line. Remaining lines will be ignored.
+    /// Path to file containing the second line. The complete file will be processed.
     #[structopt(long)]
     file2: Option<PathBuf>,
 
@@ -66,7 +67,9 @@ pub struct Config {
 impl Config {
     /// Create a config struct by using command line arguments
     pub fn from_cmd_args() -> Config {
-        Config::from_args()
+        let mut c = Config::from_args();
+        c.separators.push('\n');
+        c
     }
 
     /// Create a Config struct that can be used to compare two lines that are given as &str
@@ -169,26 +172,18 @@ fn verify_existing_file(path: &Path) -> Result<()> {
     }
 }
 
-fn get_line_from_file(path: &Path) -> Result<LineData> {
+fn get_lines_from_file(path: &Path) -> Result<LineData> {
     verify_existing_file(path)?;
 
     let file = File::open(path)?;
-    let reader = BufReader::new(file);
+    let mut reader = BufReader::new(file);
 
     let mut s = "".to_owned();
-    for (index, line) in reader.lines().enumerate() {
-        let line = line?;
-
-        if index == 0 {
-            s = line.to_owned();
-        } else {
-            println!("File contains additional lines that will be ignored");
-            break;
-        }
-    }
-    let file_name = if let Some(file_name2) = path.file_name() {
-        if let Ok(file_name3) = file_name2.to_os_string().into_string() {
-            file_name3
+    reader.read_to_string(&mut s)?;
+    
+    let file_name = if let Some(file_name) = path.file_name() {
+        if let Ok(file_name) = file_name.to_os_string().into_string() {
+            file_name
         } else {
             "".into()
         }
@@ -198,7 +193,7 @@ fn get_line_from_file(path: &Path) -> Result<LineData> {
     Ok(LineData::new(&file_name, &s))
 }
 
-fn get_lines_from_file(path: &Path) -> Result<(LineData, LineData)> {
+fn get_two_lines_from_file(path: &Path) -> Result<(LineData, LineData)> {
     verify_existing_file(path)?;
 
     let file = File::open(path).unwrap();
@@ -230,7 +225,7 @@ fn get_line_from_cmd(line_number: i32) -> LineData {
 
 fn get_line(line_number: i32, filepath: Option<PathBuf>) -> Result<LineData> {
     match filepath {
-        Some(filepath) => get_line_from_file(&*filepath),
+        Some(filepath) => get_lines_from_file(&*filepath),
         None => Ok(get_line_from_cmd(line_number)),
     }
 }
@@ -297,7 +292,7 @@ fn write_output(file: Option<PathBuf>, content: &str) {
 pub fn compare_lines(config: Config) -> Result<()> {
     let (mut s1, mut s2) = if let Some(filepath) = config.file {
         verify_existing_file(&*filepath)?;
-        get_lines_from_file(&*filepath)?
+        get_two_lines_from_file(&*filepath)?
     } else {
         let l1 = if let Some(l1) = config.line1 {
             LineData::new("Line 1", &l1)
@@ -312,8 +307,8 @@ pub fn compare_lines(config: Config) -> Result<()> {
         (l1, l2)
     };
 
-    println!("{}: \n{}", s1.name, s1.line);
-    println!("{}: \n{}", s2.name, s2.line);
+    //println!("{}: \n{}", s1.name, s1.line);
+    //println!("{}: \n{}", s2.name, s2.line);
 
     s1.preprocess_chunks(&config.separators, config.sort, config.lowercase);
     s2.preprocess_chunks(&config.separators, config.sort, config.lowercase);
@@ -383,15 +378,15 @@ mod tests {
 
     #[test]
     fn read_one_line() -> Result<()> {
-        let l1 = get_line_from_file(Path::new("examples/test.txt"))?;
+        let l1 = get_lines_from_file(Path::new("examples/test.txt"))?;
         assert_eq!("test.txt", l1.name);
-        assert_eq!("Hello world 1 3 .", l1.line);
+        assert_eq!("Hello world 1 3 .\r\nas the %+3^ night", l1.line);
         Ok(())
     }
 
     #[test]
     fn read_two_lines() -> Result<()> {
-        let (l1, l2) = get_lines_from_file(Path::new("examples/test.txt"))?;
+        let (l1, l2) = get_two_lines_from_file(Path::new("examples/test.txt"))?;
         assert_eq!("Line 1", l1.name);
         assert_eq!("Line 2", l2.name);
         assert_eq!("Hello world 1 3 .", l1.line);
